netapp_ontap.models.svm_migration_time_metrics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.svm_migration_time_metrics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SvmMigrationTimeMetricsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmMigrationTimeMetrics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cutover_complete_time: ImpreciseDateTime GET`

    Cutover end time

    Example: 2020-12-03T03:30:19.000+0000

  `cutover_start_time: ImpreciseDateTime GET`

    Cutover start time

    Example: 2020-12-03T02:20:19.000+0000

  `cutover_trigger_time: ImpreciseDateTime GET`

    Cutover trigger time

    Example: 2020-12-03T03:15:19.000+0000

  `end_time: ImpreciseDateTime GET`

    Migration end time

    Example: 2020-12-03T03:36:19.000+0000

  `last_pause_time: ImpreciseDateTime GET`

    Last migration pause time

    Example: 2020-12-03T02:50:19.000+0000

  `last_post_ponr_retry_time: ImpreciseDateTime GET`

    Last post point of no return retry time

    Example: 2020-12-03T03:30:19.000+0000

  `last_resume_time: ImpreciseDateTime GET`

    Last migration resume time

    Example: 2020-12-03T02:54:19.000+0000

  `start_time: ImpreciseDateTime GET`

    Migration start time

    Example: 2020-12-03T02:36:19.000+0000